==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/OriginDetails.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class OriginDetails(productId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.OriginDetails = {
    import OriginDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.OriginDetails
      .builder()
      .productId(__string.unwrap(productId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.OriginDetails.ReadOnly =
    zio.aws.dataexchange.model.OriginDetails.wrap(buildAwsValue())
}
object OriginDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.OriginDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.OriginDetails =
      zio.aws.dataexchange.model.OriginDetails(productId)
    def productId: __string
    def getProductId: ZIO[Any, Nothing, __string] = ZIO.succeed(productId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.OriginDetails
  ) extends zio.aws.dataexchange.model.OriginDetails.ReadOnly {
    override val productId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.productId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.OriginDetails
  ): zio.aws.dataexchange.model.OriginDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.17.295.15-sources.jar: zio/aws/dataexchange/model/OriginDetails.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class OriginDetails(productId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.OriginDetails = {
    import OriginDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.OriginDetails
      .builder()
      .productId(productId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.OriginDetails.ReadOnly =
    zio.aws.dataexchange.model.OriginDetails.wrap(buildAwsValue())
}
object OriginDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.OriginDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.OriginDetails =
      zio.aws.dataexchange.model.OriginDetails(productId)
    def productId: __string
    def getProductId: ZIO[Any, Nothing, __string] = ZIO.succeed(productId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.OriginDetails
  ) extends zio.aws.dataexchange.model.OriginDetails.ReadOnly {
    override val productId: __string = impl.productId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.OriginDetails
  ): zio.aws.dataexchange.model.OriginDetails.ReadOnly = new Wrapper(impl)
}
